@@ -136,46 +136,3 @@ phylosig<-function(tree,x,method="K",test=FALSE,nsim=1000,se=NULL,start=NULL,con
 		stop(paste("do not recognize method = \"",method,"\"; methods are \"K\" and \"lambda\"",sep=""))
 }
 
-# function
-# written by Liam J. Revell 2011
-
-matchDatatoTree<-function(tree,x,name){
-	if(is.matrix(x)) x<-x[,1]
-	if(is.null(names(x))){
-		if(length(x)==length(tree$tip)){
-			print(paste(name,"has no names; assuming x is in the same order as tree$tip.label"))
-			names(x)<-tree$tip.label
-		} else
-			stop(paste(name,"has no names and is a different length than tree$tip.label"))
-	}
-	if(any(is.na(match(names(x),tree$tip.label)))){
-		print(paste("some species in",name,"are missing from tree, dropping missing taxa from",name))
-		x<-x[intersect(tree$tip.label,names(x))]
-	}
-	return(x)
-}
-
-# function
-# written by Liam J. Revell 2011
-
-matchTreetoData<-function(tree,x,name){
-	if(any(is.na(match(tree$tip.label,names(x))))){
-		print(paste("some species in tree are missing from",name,", dropping missing taxa from the tree"))
-		tree<-drop.tip(tree,setdiff(tree$tip.label,names(x)))
-	}
-	if(any(is.na(x))){
-		print(paste("some data in",name,"given as 'NA', dropping corresponding species from tree"))
-		tree<-drop.tip(tree,names(which(is.na(x))))
-	}
-	return(tree)
-}
-
-# function
-# written by Liam J. Revell 2011
-
-maxLambda<-function(tree){
-	if(is.ultrametric(tree)){
-		H<-nodeHeights(tree)
-		return(max(H[,2])/max(H[,1]))
-	} else return(1)
-}
