@@ -1,5 +1,5 @@
 # function plots a tree; in the new version this is just a wrapper for plotSimmap
-# written by Liam Revell 2012
+# written by Liam Revell 2012, 2013
 
 plotTree<-function(tree,...){
 	if(hasArg(color)) color<-list(...)$color
@@ -20,14 +20,18 @@ plotTree<-function(tree,...){
 	else add<-FALSE
 	if(hasArg(offset)) offset<-list(...)$offset
 	else offset<-NULL
+	# if(hasArg(shift)) shift<-list(...)$shift
+	# else shift<-NULL
+	if(hasArg(direction)) direction<-list(...)$direction
+	else direction<-"rightwards"
 	if(class(tree)=="multiPhylo"){
 		par(ask=TRUE)
 		if(!is.null(color)) names(color)<-"1"
-		for(i in 1:length(tree)) plotTree(tree[[i]],color=color,fsize=fsize,ftype=ftype,lwd=lwd,pts=pts,node.numbers=node.numbers,mar=mar,add=add,offset=offset)
+		for(i in 1:length(tree)) plotTree(tree[[i]],color=color,fsize=fsize,ftype=ftype,lwd=lwd,pts=pts,node.numbers=node.numbers,mar=mar,add=add,offset=offset,direction=direction)
 	} else {
 		tree$maps<-as.list(tree$edge.length)
 		for(i in 1:length(tree$maps)) names(tree$maps[[i]])<-c("1")
 		if(!is.null(color)) names(color)<-"1"
-		plotSimmap(tree,colors=color,fsize=fsize,ftype=ftype,lwd=lwd,pts=pts,node.numbers=node.numbers,mar=mar,add=add,offset=offset)
+		plotSimmap(tree,colors=color,fsize=fsize,ftype=ftype,lwd=lwd,pts=pts,node.numbers=node.numbers,mar=mar,add=add,offset=offset,direction=direction)
 	}
 }
