@@ -3,8 +3,8 @@
 
 rescaleSimmap<-function(tree,totalDepth=1.0){
 	if(class(tree)=="multiPhylo"){
-		trees<-list(); class(trees)<-"multiPhylo"
 		trees<-lapply(tree,rescaleSimmap,totalDepth)
+		class(trees)<-"multiPhylo"
 		return(trees)
 	} else if(class(tree)=="phylo"){
 		h<-max(nodeHeights(tree))
